@@ -28,7 +28,7 @@
 #include "asfheaders.h"
 
 G_BEGIN_DECLS
-
+  
 #define GST_TYPE_ASF_DEMUX \
   (gst_asf_demux_get_type())
 #define GST_ASF_DEMUX(obj) \
@@ -45,7 +45,6 @@ GST_DEBUG_CATEGORY_EXTERN (asfdemux_dbg);
 
 typedef struct _GstASFDemux GstASFDemux;
 typedef struct _GstASFDemuxClass GstASFDemuxClass;
-typedef enum _GstASF3DMode GstASF3DMode;
 
 typedef struct {
   guint32	packet;
@@ -58,21 +57,6 @@ typedef struct {
   guint16                 len;      /* save this so we can skip unknown IDs  */
 } AsfPayloadExtension;
 
-/*
- * 3D Types for Media play
- */
-enum _GstASF3DMode
-{
-  GST_ASF_3D_NONE = 0x00,
-
-  //added, interim format - half
-  GST_ASF_3D_SIDE_BY_SIDE_HALF_LR = 0x01,
-  GST_ASF_3D_SIDE_BY_SIDE_HALF_RL = 0x02,
-  GST_ASF_3D_TOP_AND_BOTTOM_HALF_LR = 0x03,
-  GST_ASF_3D_TOP_AND_BOTTOM_HALF_RL = 0x04,
-  GST_ASF_3D_DUAL_STREAM = 0x0D,                  /*< Full format*/
-};
-
 typedef struct
 {
   gboolean        valid;               /* TRUE if structure is valid/filled */
@@ -112,12 +96,9 @@ typedef struct
 
   GstCaps    *caps;
 
-  GstBuffer *streamheader;
-
   GstTagList *pending_tags;
 
   gboolean    discont;
-  gboolean    first_buffer;
 
   /* Descrambler settings */
   guint8               span;
@@ -133,14 +114,9 @@ typedef struct
   guint8	par_y;
   gboolean      interlaced;
 
-  /* For reverse playback */
-  gboolean	reverse_kf_ready; /* Found complete KF payload*/
-  GArray	*payloads_rev; /* Temp queue for storing multiple payloads of packet*/
-  gint		kf_pos; /* KF position in payload queue. Payloads from this pos will be pushed */
-
   /* extended stream properties (optional) */
   AsfStreamExtProps  ext_props;
-
+  
   gboolean     inspect_payload;
 } AsfStream;
 
@@ -150,8 +126,6 @@ typedef enum {
   GST_ASF_DEMUX_STATE_INDEX
 } GstASFDemuxState;
 
-#define GST_ASF_DEMUX_IS_REVERSE_PLAYBACK(seg) (seg.rate < 0.0? TRUE:FALSE)
-
 #define GST_ASF_DEMUX_NUM_VIDEO_PADS   16
 #define GST_ASF_DEMUX_NUM_AUDIO_PADS   32
 #define GST_ASF_DEMUX_NUM_STREAMS      32
@@ -212,7 +186,6 @@ struct _GstASFDemux {
   gboolean             broadcast;
 
   GstSegment           segment;          /* configured play segment                 */
-  gboolean             keyunit_sync;
   gboolean             accurate;
 
   gboolean             need_newsegment;  /* do we need to send a new-segment event? */
@@ -231,17 +204,8 @@ struct _GstASFDemux {
   GstClockTime         sidx_interval;    /* interval between entries in ns */
   guint                sidx_num_entries; /* number of index entries        */
   AsfSimpleIndexEntry *sidx_entries;     /* packet number for each entry   */
-
+  
   GSList              *other_streams;    /* remember streams that are in header but have unknown type */
-
-  /* For reverse playback */
-  gboolean             seek_to_cur_pos; /* Search packets till we reach 'seek' time */
-  gboolean             multiple_payloads; /* Whether packet has multiple payloads */
-
-  /* parsing 3D */
-  GstASF3DMode asf_3D_mode;
-
-  gboolean saw_file_header;
 };
 
 struct _GstASFDemuxClass {
